@@ -2,7 +2,8 @@ library(testthat)
 library(highfrequency)
 library(xts)
 
-context("matchTradesQuotes & getTradeDirection quotes")
+
+# matchTradesQuotes & getTradeDirection quotes ----------------------------
 test_that("matchTradesQuotes & getTradeDirection quotes", {
   tqData <- matchTradesQuotes(sampleTData, sampleQData, lagQuotes = 2)
   directions <- getTradeDirection(tqData)
@@ -12,7 +13,8 @@ expect_equal(
   -1572
 )})
 
-context("getLiquidityMeasures")
+
+# getLiquidityMeasures ----------------------------------------------------
 test_that("testing getLiquidityMeasures",{
   
   tqData <- tradesCleanupUsingQuotes(tData = tradesCleanup(tDataRaw = sampleTDataRaw, report = FALSE, exchanges = "N"), 
@@ -33,31 +35,15 @@ test_that("testing getLiquidityMeasures",{
                #   
                #   
                
-               c("midpoints" = 1.568751203e+02,
-               "direction" = -1.646205357e-01,
-               "effectiveSpread" = 2.116099330e-02,
-               "realizedSpread" = -1.730314502e-02,
-               "valueTrade" = 2.587442590e+04,
-               "signedValueTrade" = -3.525860704e+03,
-               "depthImbalanceDifference" = 2.679893658e-03,
-               "depthImbalanceRatio" = -3.060161477e-01,
-               "proportionalEffectiveSpread" = 1.346079032e-04,
-               "proportionalRealizedSpread" = -1.082144587e-04,
-               "priceImpact" = 1.944379732e-02,
-               "proportionalPriceImpact" = 1.227587276e-04,
-               "halfTradedSpread" = 1.058049665e-02,
-               "proportionalHalfTradedSpread" = 6.730395161e-05,
-               "squaredLogReturn" = 2.510765091e-08,
-               "absLogReturn" = 1.014482187e-04,
-               "quotedSpread" = 4.554896763e-02,
-               "proportionalQuotedSpread" = 2.898679017e-04,
-               "logQuotedSpread" = 2.898679107e-04 ,
-               "logQuotedSize" = 3.406315538e+00,
-               "quotedSlope" = 1.939226740e-02,
-               "logQSlope" = 1.233647337e-04,
-               "midQuoteSquaredReturn" = 1.752787460e-08,
-               "midQuoteAbsReturn" = 8.566642940e-05 ,
-               "signedTradeSize" = -2.252273996e+01))
+               c("midpoints" = 1.568751203e+02, "direction" = -1.646205357e-01, "effectiveSpread" = 2.116099330e-02,
+                 "realizedSpread" = -1.730314502e-02, "valueTrade" = 2.587442590e+04, "signedValueTrade" = -3.525860704e+03,
+                 "depthImbalanceDifference" = 2.679893658e-03, "depthImbalanceRatio" = -3.060161477e-01, "proportionalEffectiveSpread" = 1.346079032e-04,
+                 "proportionalRealizedSpread" = -1.082144587e-04, "priceImpact" = 1.944379732e-02, "proportionalPriceImpact" = 1.227587276e-04,
+                 "halfTradedSpread" = 1.058049665e-02, "proportionalHalfTradedSpread" = 6.730395161e-05, "squaredLogReturn" = 2.510765091e-08,
+                 "absLogReturn" = 1.014482187e-04, "quotedSpread" = 4.554896763e-02, "proportionalQuotedSpread" = 2.898679017e-04,
+                 "logQuotedSpread" = 2.898679107e-04, "logQuotedSize" = 3.406315538e+00, "quotedSlope" = 1.939226740e-02,
+                 "logQSlope" = 1.233647337e-04, "midQuoteSquaredReturn" = 1.752787460e-08, "midQuoteAbsReturn" = 8.566642940e-05,
+                 "signedTradeSize" = -2.252273996e+01))
                
                   
   
